"use strict";
/// <reference path="../../node_modules/typescript/lib/lib.dom.d.ts" />
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// Ensure window object exists & is accessible
var window = window || {}; // tslint:disable-line:no-var-keyword
/******************************************** IMPORTS *********************************************/
var detect_node_1 = __importDefault(require("detect-node"));
/**************************************** PROJECT IMPORTS *****************************************/
var fnName = 'mad-utils::event';
var isomorphic_enforcement_1 = require("../internal/isomorphic-enforcement");
/**************************************** DEFAULTS, CONFIG ****************************************/
// TODO probably remove this
// Default global
var global = (detect_node_1.default)
    ? global
    : ((typeof window !== 'undefined')
        ? window
        : global);
/**************************************** EXPORT FUNCTIONS ****************************************/
/**
 * Construct a new click event. Can optionally pass in a global object.
 * Generic event remover. Only works in browser unless allowInNode set.
 * @return {MouseEvent} Browser: newly constructed MouseEvent object. Node: null.
 * @param {boolean} allowInNode - If set to true, let this run in Node anyway. Defaults to false.
 */
exports.mouseEventFactory = 
// Adjust behaviour based on whether this is running in Node or browser.
detect_node_1.default
    // Return null and show a warning if run in Node.
    ? function (globalTarget) {
        if (globalTarget === void 0) { globalTarget = global; }
        isomorphic_enforcement_1.browserOnly('mouseEventFactory');
        return null;
    }
    // Return triggerable built-in event if run in browser.
    : function (globalTarget) {
        if (globalTarget === void 0) { globalTarget = window; }
        return new MouseEvent('click', {
            'view': globalTarget,
            'bubbles': true,
            'cancelable': true
        });
    };
/**
 * Generic event remover.
 * In Node: returns null and emits warning that this can only works in the browser.
 * In browser: return function w signature:
 *     (ev?: MouseEvent) => void
 *     Running it removes matching MouseEvent from the element passed to the parent.
 *     Reason: The outputted function can be assigned as a clicked handler (e.g., in React).
 */
exports.removeClickEventFromId = detect_node_1.default
    ? function (id, event) {
        if (id === void 0) { id = ''; }
        if (event === void 0) { event = null; }
        isomorphic_enforcement_1.browserOnly('removeClickEventFromId');
        return null;
    }
    : function (id, event) { return function (ev) {
        document.getElementById
            && document.getElementById(id).removeEventListener('click', event);
    }; };
// Generic event adder: addEventToId('id-event-2', function(ev: MouseEvent) { alert('doThing') });
exports.addClickEventToId = detect_node_1.default
    ? function (id, event) {
        if (id === void 0) { id = ''; }
        if (event === void 0) { event = null; }
        isomorphic_enforcement_1.browserOnly('addClickEventToId');
        return null;
    }
    : function (id, cb) {
        document.getElementById
            && document.getElementById(id).addEventListener('click', cb, false);
    };
//# sourceMappingURL=event.js.map