"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var string_1 = require("./string");
exports.escapeRegExp = string_1.escapeRegExp;
exports.matches = string_1.matches;
exports.matchesIgnoreCase = string_1.matchesIgnoreCase;
exports.replaceAll = string_1.replaceAll;
/**
 * Perform actual fuzzy search
 */
var fSearch = function (needle, haystack) {
    outerLoop: for (var nPos = 0, hPos = 0; nPos < needle.length; nPos++) {
        while (hPos < haystack.length) {
            if (haystack.charCodeAt(hPos) === needle.charCodeAt(nPos)) {
                continue outerLoop;
            }
            if (hPos > 0 && haystack.charCodeAt(hPos - 1) === needle.charCodeAt(nPos)) {
                continue outerLoop;
            }
            hPos++;
        }
        return false;
    }
    return true;
};
/**
 * Ultra-forgiving fuzzy search for {string} needle, in {string} haystack
 * Search is done both forwards and backwards to catch inverted key errors
 *
 * @param {string} needle Fuzzy-search for this string within string haystack
 * @param {string} haystack Fuzzy-search for string needle within this string
 * @return {boolean} True if needle found (roughly) in haystack
 */
exports.fuzzySearch = function (needle, haystack) {
    // If no needle, always return true
    if (!needle)
        return true;
    var needleLowercase = needle.toLowerCase();
    var haystackLowercase = haystack.toLowerCase();
    // Perform basic searches (for performance), return true on success
    var haystackLength = haystack.length;
    var needleLength = needle.length;
    if (!haystack || needleLength > haystackLength)
        return false;
    if (needleLength === haystackLength && needleLowercase === haystackLowercase)
        return true;
    // Perform fuzzy search
    return fSearch(needleLowercase, haystackLowercase);
};
//# sourceMappingURL=search.js.map