"use strict";
/// <reference path="../../node_modules/@types/mocha/index.d.ts" />
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/******************************************* TEST SETUP *******************************************/
var enzyme_1 = __importDefault(require("enzyme"));
var enzyme_adapter_react_16_1 = __importDefault(require("enzyme-adapter-react-16"));
enzyme_1.default.configure({ adapter: new enzyme_adapter_react_16_1.default() });
/*************************************** IMPORT TEST UTILS ****************************************/
var react_1 = __importDefault(require("react"));
var chai_1 = require("chai");
var enzyme_2 = require("enzyme");
var test_1 = require("../../src/node/test");
/******************************** IMPORT NUMBER MODULE FOR TESTING ********************************/
var components_1 = require("../../src/react/components");
/******************************************** LOGGING *********************************************/
var shared_1 = require("mad-logs/lib/shared");
var log = shared_1.logFactory("react--components.spec.tsx", shared_1.Styles.hatBlock);
/******************************************** HELPERS *********************************************/
/**
 * Gets number of children of the rendered component
 * @example numChildren(shallow(
 *              <div>
 *                  <span>El 1</span>
 *                  <span>El 2</span>
 *              </div>
 *          )); // => 2
 */
var numChildren = function (cmp) { return cmp.children().length; };
/**
 * Gets the child of the rendered component
 * @example getChildNode(shallow(<div>Hello</div>)); // => 'Hello'
 */
var getChildNode = function (cmp) {
    return cmp
        .children()
        .first()
        .text();
};
var TestClass = /** @class */ (function (_super) {
    __extends(TestClass, _super);
    function TestClass() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TestClass.prototype.render = function () {
        return react_1.default.createElement("div", null, "ok");
    };
    return TestClass;
}(react_1.default.Component));
/********************************************* TESTS **********************************************/
describe("React module", function () {
    test_1.expectFunctionExists(components_1.Switch, 'Switch', '(React utility component)');
    test_1.expectFunctionExists(components_1.Case, 'Case', '(React utility component)');
    test_1.expectFunctionExists(components_1.Default, 'Default', '(React utility component)');
    describe("IfTruthy, IfFalsy", function () {
        var trueElement = react_1.default.createElement("div", null, "true child");
        var falseElement = react_1.default.createElement("div", null, "false child");
        test_1.expectFunctionExists(components_1.IfTruthy, 'IfTruthy', '(React utility component)');
        test_1.expectFunctionExists(components_1.IfFalsy, 'IfFalsy', '(React utility component)');
        describe("IfTruthy", function () {
            var wrappedTruthyTrue;
            var wrappedTruthyFalse;
            before(function () {
                wrappedTruthyTrue = enzyme_2.shallow(react_1.default.createElement(components_1.IfTruthy, { test: true }, trueElement));
                wrappedTruthyFalse = enzyme_2.shallow(react_1.default.createElement(components_1.IfTruthy, { test: false }, falseElement));
            });
            it("Renders children if value given to prop 'test' is truthy", function () {
                chai_1.expect(numChildren(wrappedTruthyTrue)).to.equal(1);
                chai_1.expect(getChildNode(wrappedTruthyTrue)).to.equal('true child');
            });
            it("Does not render children if value given to prop 'test' is not truthy", function () {
                chai_1.expect(numChildren(wrappedTruthyFalse)).to.eql(0);
                chai_1.expect(wrappedTruthyFalse.props().children).to.be.undefined;
            });
        });
        describe("IfFalsy", function () {
            var wrappedFalsyTrue;
            var wrappedFalsyFalse;
            before(function () {
                wrappedFalsyTrue = enzyme_2.shallow(react_1.default.createElement(components_1.IfFalsy, { test: true }, falseElement));
                wrappedFalsyFalse = enzyme_2.shallow(react_1.default.createElement(components_1.IfFalsy, { test: false }, trueElement));
            });
            it("Renders children if value given to prop 'test' is falsy", function () {
                chai_1.expect(numChildren(wrappedFalsyFalse)).to.eql(1);
                chai_1.expect(getChildNode(wrappedFalsyFalse)).to.equal('true child');
            });
            it("Does not render children if value given to prop 'test' is not falsy", function () {
                chai_1.expect(numChildren(wrappedFalsyTrue)).to.eql(0);
                chai_1.expect(wrappedFalsyTrue.props().children).to.be.undefined;
            });
        });
        describe("Switch-Case-Default component structure/collection", function () {
            var switch_caseMatch_noDef;
            var switch_noCaseMatch_def;
            var switch_caseMatch_def_strRet;
            var switch_noCaseMatch_noDef;
            test_1.expectFunctionExists(components_1.Switch, 'Switch', '(React utility component)');
            test_1.expectFunctionExists(components_1.Case, 'Case', '(React utility component)');
            test_1.expectFunctionExists(components_1.Default, 'Default', '(React utility component)');
            before(function () {
                switch_caseMatch_noDef = enzyme_2.shallow(react_1.default.createElement(components_1.Switch, { test: true },
                    react_1.default.createElement(components_1.Case, { val: false },
                        react_1.default.createElement("div", null, "CASE1_should_not_match")),
                    react_1.default.createElement(components_1.Case, { val: true },
                        react_1.default.createElement("div", null, "CASE2_should_match"))));
                switch_noCaseMatch_def = enzyme_2.shallow(react_1.default.createElement(components_1.Switch, { test: 'test_str_w_no_matching_child_case' },
                    react_1.default.createElement(components_1.Case, { val: false },
                        react_1.default.createElement("div", null, "CASE1_should_not_match")),
                    react_1.default.createElement(components_1.Case, { val: false },
                        react_1.default.createElement("div", null, "CASE2_should_not_match")),
                    react_1.default.createElement(components_1.Default, null,
                        react_1.default.createElement("span", null, "DEFAULT_should_match"))));
                switch_caseMatch_def_strRet = enzyme_2.shallow(react_1.default.createElement(components_1.Switch, { test: 'MATCHING_CASE' },
                    react_1.default.createElement(components_1.Case, { val: '__NOT_A_MATCH__' },
                        react_1.default.createElement("div", null, "CASE1_should_not_match")),
                    react_1.default.createElement(components_1.Case, { val: 'MATCHING_CASE' }, "CASE2_str_should_match"),
                    react_1.default.createElement(components_1.Default, null,
                        react_1.default.createElement("span", null, "DEFAULT_should_not_match"))));
            });
            it("Returns the content of a matching <Case>, with <Default> defined", function () {
                chai_1.expect(switch_caseMatch_noDef.is('div')).to.be.true;
                chai_1.expect(getChildNode(switch_caseMatch_noDef)).to.eql('CASE2_should_match');
            });
            it("Returns the content of <Default> if no <Case val={x}> matches", function () {
                chai_1.expect(switch_noCaseMatch_def.is('span')).to.be.true;
                chai_1.expect(getChildNode(switch_noCaseMatch_def)).to.eql('DEFAULT_should_match');
            });
            it("Returns matching <Case> child wrapped in span if child is a plain str", function () {
                chai_1.expect(switch_caseMatch_def_strRet.is('span')).to.be.true;
                chai_1.expect(getChildNode(switch_caseMatch_def_strRet)).to.eql('CASE2_str_should_match');
            });
        });
    });
});
//# sourceMappingURL=react--components.spec.js.map